## VegaFusion
This package is part of the VegaFusion project: https://vegafusion.io.

In particular, the `vegafusion` package provides a pure Python interface to a VegaFusion Runtime. Initially, the only runtime available is provided by the `vegafusion-python-embed` package. Eventually, the VegaFusion runtime will be available as a standalone gRPC server and this package will be updated to support communication with a VegaFusion Runtime over gRPC as an alternative to the Runtime provided by `vegafusion-python-embed`.  
